"""
Type annotations for s3transfer.constants module.

Copyright 2025 Vlad Emelianov
"""

KB: int = ...
MB: int = ...
GB: int = ...
ALLOWED_DOWNLOAD_ARGS: list[str] = ...
FULL_OBJECT_CHECKSUM_ARGS: list[str] = ...
USER_AGENT: str = ...
PROCESS_USER_AGENT: str = ...



"""
Type annotations for s3transfer.compat module.

Copyright 2025 Vlad Emelianov
"""

import os
from multiprocessing.managers import BaseManager as _BaseManager
from typing import IO, Any, Callable

rename_file = os.rename

class BaseManager(_BaseManager): ...

def accepts_kwargs(func: Callable[..., Any]) -> bool: ...

SOCKET_ERROR: type[ConnectionError]
MAXINT: None

def seekable(fileobj: IO[Any] | str | bytes) -> bool: ...
def readable(fileobj: IO[Any] | str | bytes) -> bool: ...
def fallocate(fileobj: IO[Any] | str | bytes, size: int) -> None: ...



"""
Type annotations for s3transfer.delete module.

Copyright 2025 Vlad Emelianov
"""

from s3transfer.tasks import SubmissionTask as SubmissionTask
from s3transfer.tasks import Task as Task

class DeleteSubmissionTask(SubmissionTask): ...
class DeleteObjectTask(Task): ...



"""
Type annotations for s3transfer.tasks module.

Copyright 2025 Vlad Emelianov
"""

import logging
from typing import Any, Callable, Sequence

from botocore.context import ClientContext
from s3transfer.futures import TransferCoordinator
from s3transfer.utils import get_callbacks as get_callbacks

logger: logging.Logger

class Task:
    def __init__(
        self,
        transfer_coordinator: TransferCoordinator,
        main_kwargs: dict[str, Any] | None = ...,
        pending_main_kwargs: dict[str, Any] | None = ...,
        done_callbacks: Sequence[Callable[..., Any]] | None = ...,
        is_final: bool = ...,
    ) -> None: ...
    @property
    def transfer_id(self) -> str: ...
    def __call__(self, ctx: ClientContext | None = None) -> None: ...

class SubmissionTask(Task): ...
class CreateMultipartUploadTask(Task): ...
class CompleteMultipartUploadTask(Task): ...
